"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_extra_1 = require("fs-extra");
const path_1 = require("path");
const graphql_1 = require("graphql");
const ast_1 = require("graphql-tool-utilities/ast");
const validate_1 = require("./validate");
function evaluateFixtures({ fixturePaths, operationPaths = [], schemaPath }, { schemaOnly = false } = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        let schema;
        try {
            const schemaJSON = yield fs_extra_1.readJSON(schemaPath, 'utf8');
            schema = graphql_1.buildClientSchema(schemaJSON.data);
        }
        catch (error) {
            throw new Error(`Error parsing '${schemaPath}':\n\n${error.message.replace(/Syntax Error GraphQL \(.*?\) /, '')}`);
        }
        if (schemaOnly) {
            return yield runForEachFixture(fixturePaths, (fixture) => validate_1.validateFixtureAgainstSchema(fixture, schema));
        }
        const sources = yield Promise.all(operationPaths.map((operationPath) => __awaiter(this, void 0, void 0, function* () { return new graphql_1.Source(yield fs_extra_1.readFile(operationPath, 'utf8'), operationPath); })));
        const document = graphql_1.concatAST(sources.map((source) => {
            try {
                return graphql_1.parse(source);
            }
            catch (error) {
                throw new Error(`Error parsing '${source.name}':\n\n${error.message.replace(/Syntax Error.*?\(.*?\) /, '')}`);
            }
        }));
        const ast = ast_1.compile(schema, document);
        return yield runForEachFixture(fixturePaths, (fixture) => validate_1.validateFixtureAgainstAST(fixture, ast));
    });
}
exports.evaluateFixtures = evaluateFixtures;
function runForEachFixture(fixturePaths, runner) {
    return Promise.all(fixturePaths.map((fixturePath) => __awaiter(this, void 0, void 0, function* () {
        const finalPath = path_1.isAbsolute(fixturePath) ? fixturePath : path_1.resolve(fixturePath);
        try {
            const fixture = yield fs_extra_1.readJSON(finalPath);
            return Object.assign({ fixturePath: finalPath }, runner({ path: finalPath, content: fixture }));
        }
        catch (error) {
            return {
                fixturePath: finalPath,
                scriptError: error,
                validationErrors: [],
            };
        }
    })));
}
